/* ===========================================================
 * JFreeChart : a free chart library for the Java(tm) platform
 * ===========================================================
 *
 * (C) Copyright 2000-2004, by Object Refinery Limited and Contributors.
 *
 * Project Info:  http://www.jfree.org/jfreechart/index.html
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
 * in the United States and other countries.]
 *
 * ---------------------
 * TimePeriodAnchor.java
 * ---------------------
 * (C) Copyright 2003 by Object Refinery Limited.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 * Contributor(s):   -;
 *
 * $Id: TimePeriodAnchor.java,v 1.2 2004/01/05 17:11:49 mungady Exp $
 *
 * Changes:
 * --------
 * 30-Jul-2003 : Version 1 (DG);
 *
 */

package org.jfree.data.time;

import java.io.Serializable;

/**
 * Used to indicate one of three positions in a time period: <code>START</code>, 
 * <code>MIDDLE</code> and <code>END</code>.
 *
 * @author David Gilbert
 */
public final class TimePeriodAnchor implements Serializable {

    /** Start of period. */
    public static final TimePeriodAnchor START = new TimePeriodAnchor("TimePeriodAnchor.START");

    /** Middle of period. */
    public static final TimePeriodAnchor MIDDLE = new TimePeriodAnchor("TimePeriodAnchor.MIDDLE");

    /** End of period. */
    public static final TimePeriodAnchor END = new TimePeriodAnchor("TimePeriodAnchor.END");

    /** The name. */
    private String name;

    /**
     * Private constructor.
     *
     * @param name  the name.
     */
    private TimePeriodAnchor(String name) {
        this.name = name;
    }

    /**
     * Returns a string representing the object.
     *
     * @return The string.
     */
    public String toString() {
        return this.name;
    }

    /**
     * Returns <code>true</code> if this object is equal to the specified object, and
     * <code>false</code> otherwise.
     *
     * @param o  the other object.
     *
     * @return A boolean.
     */
    public boolean equals(Object o) {

        if (this == o) {
            return true;
        }
        if (!(o instanceof TimePeriodAnchor)) {
            return false;
        }

        final TimePeriodAnchor position = (TimePeriodAnchor) o;
        if (!this.name.equals(position.toString())) {
            return false;
        }

        return true;

    }

}
