/*
 * Created on 5 avr. 2003
 * (c) Alexandre Brillant / JAPISOFT 2002-2003 All rights reserved
 * */
package demo;

import java.util.*;

/**
 *  Start test from a properties file. This test loads ParserTester class and apply
 * 100 iterations. It measures the first access and the last access and an average result.
 */
public class TestLauncher {
    Properties prop;
    String file;
    int it;

    public TestLauncher( String file, String it ) throws Throwable {
	prop = new Properties();
	prop.load( ClassLoader.getSystemResourceAsStream( "demo/tests.prop" ) );
	this.file = file;
	try {
	this.it = Integer.parseInt( it );
	} catch( Throwable th ) {
	    this.it = 100;
	}
    }
		
    private void test( ParserTester test ) {
	try {
	    long total = 0;
	    for ( int i = 0; i < it; i++ ) {
		long init = System.currentTimeMillis();
		test.start( file);
		long delay = ( System.currentTimeMillis() - init );
		if ( i == 0) {
		    System.out.println( "- First time :" + delay + " ms");
		} else
		    if ( i == it - 1 ) {
			System.out.println( "- Last time :" + delay + " ms");
		    }
		total += delay;
	    }
	    System.out.println( "- Average time : " + ( total / it ) + " ms" );
	} catch( Throwable th ) {
	    System.out.println( "Error : " + th.getMessage());
	}
    }
		
    public void start() throws Throwable {
	System.out.println( "********* Starting Evaluation ************" );
	for ( Enumeration enum = prop.keys(); enum.hasMoreElements(); ) {
	    String testId = (String)enum.nextElement();
	    String className = prop.getProperty( testId );
	    System.out.println( "** Starting test for : " + testId + "/" + className );
	    try {
		ParserTester test = (ParserTester)( ( Class.forName( className ) ).newInstance() );
		test( test );
	    } catch( Throwable th ) {
		th.printStackTrace();System.out.println( "Can't use " + className );
	    }
			
			
	}
	System.out.println( "********* End of evaluation **************");
    }
	

    public static void main( String[] args) throws Throwable{
	TestLauncher tl = new TestLauncher( args[ 0 ], args[ 1 ] );
	tl.start();
    }
}
